@@ -1,21 +1,24 @@
+import os
 import re
+import subprocess
 import sys
 import textwrap
 import time
 from pathlib import Path
 
-# Functions in utils should be moved to cloudmesh.common
-from cloudmesh.bridge.utils import *
 from cloudmesh.common.StopWatch import StopWatch
 from cloudmesh.common.console import Console
 from cloudmesh.common.util import banner
-from cloudmesh.common.util import writefile, readfile
-
+from cloudmesh.common.util import readfile
+from cloudmesh.common.util import sudo_readfile
+from cloudmesh.common.util import writefile
+from cloudmesh.common.sudo import Sudo
 
 #
 # These methods are not parallel but just work in one processor
 #
 
+
 class Bridge:
     """
     A simple Bridge to connect workers to the internet through a port on the
@@ -26,22 +29,22 @@ class Bridge:
     ext_interface = "eth1"
     priv_interface = "eth0"
     lease = '12h'
-    master = None
-    masterIP = None
+    manager = None
+    managerIP = None
     ip_range = None
     workers = None
     dns = ['8.8.8.8', '8.8.4.4']
     lease_bookmark = '# LEASE HISTORY #'
 
     @classmethod
-    def create(cls, masterIP='10.1.1.1', ip_range=['10.1.1.2', '10.1.1.122'],
-               master=None, workers=None,
+    def create(cls, managerIP='10.1.1.1', ip_range=['10.1.1.2', '10.1.1.122'],
+               manager=None, workers=None,
                priv_interface='eth0', ext_interface='eth1', purge=False,
-               dryrun=False):
+               dryrun=False, dns='8.8.8.8'):
         """
-        if worker(s) is missing the master is set up only
+        if worker(s) is missing the manager is set up only
 
-        :param master: expected to be a single string
+        :param manager: expected to be a single string
         :param workers:
         :param ext_interface: The external interface through which the manager
                               connects to the internet
@@ -50,18 +53,20 @@ class Bridge:
         :param dryrun:
         :return:
         """
-        cls.masterIP = masterIP
+        cls.managerIP = managerIP
         cls.ip_range = ip_range
-        cls.master = master
+        cls.manager = manager
         cls.workers = workers
         cls.dryrun = dryrun
         cls.ext_interface = ext_interface
         cls.priv_interface = priv_interface
+        cls.nameserver = None if dns is None else ' '.join(dns.split(','))
+        # dhcpcd conf required nameserver IPs be separated by space
 
-        # Master configuration
+        # manager configuration
         StopWatch.start('Manager Configuration')
 
-        # Configure dhcpcd.conf of master. No restart
+        # Configure dhcpcd.conf of manager. No restart
         StopWatch.start('dhcpcd.conf configuration')
         cls._dhcpcd_conf()
         StopWatch.stop('dhcpcd.conf configuration')
@@ -110,7 +115,7 @@ class Bridge:
 
         Console.ok("Process completed")
 
-    # Set a worker to use the master
+    # Set a worker to use the manager
     @classmethod
     def set(cls, workers=None, addresses=None):
         """
@@ -189,7 +194,7 @@ class Bridge:
 
                 conf += to_add
 
-                sudo_writefile('/etc/dnsmasq.conf', '\n'.join(conf) + '\n')
+                Sudo.writefile('/etc/dnsmasq.conf', '\n'.join(conf) + '\n')
                 Console.ok("Added IP's to dnsmasq")
 
     @classmethod
@@ -209,7 +214,7 @@ class Bridge:
 
         BRIDGE        - Service running: {dhcpcdRunning and dnsmasqRunning}
         
-        """), color='CYAN')
+        """), color='CYAN')  # noqa: W293
 
     @classmethod
     def list(cls, host=None):
@@ -233,7 +238,7 @@ class Bridge:
             info = sudo_readfile('~/.cloudmesh/bridge/info')
             index = info.index(cls.lease_bookmark)
             leases = info[index + 1:]
-        except Exception as e:
+        except Exception as e:  # noqa: F841
             Console.error(
                 'Could not find information on bridge. Has the bridge been created yet?')
             sys.exit(1)
@@ -260,16 +265,16 @@ class Bridge:
                 # I believe this is a sufficient check
                 if status != 0:
                     message = textwrap.dedent(f"""
-                    Could not ping {host} successfuly.
+                    Could not ping {host} successfully.
                     
                     Rebooting {host} may fix the problem.
 
                     Manually ping {host} for more details.
-                    """)
+                    """)  # noqa: W293
                     Console.warning(message)
                 else:
                     count += 1
-                    Console.ok(f"Successfuly pinged {host}")
+                    Console.ok(f"Successfully pinged {host}")
 
         Console.ok(
             f'Completed checks. {count} out of {hosts_to_check} checks succeeded.')
@@ -285,7 +290,7 @@ class Bridge:
         # Clear lease log
         if Path('/var/lib/misc/dnsmasq.leases').is_file():
             Console.info("Clearing leases file...")
-            sudo_writefile('/var/lib/misc/dnsmasq.leases', "\n")
+            Sudo.writefile('/var/lib/misc/dnsmasq.leases', "\n")
 
         # If nohup is true, do not restart dhcpcd
         if not nohup:
@@ -293,8 +298,7 @@ class Bridge:
 
             status = cls._system('sudo service dhcpcd restart', exitcode=True)
             if status != 0:
-                Console.error(
-                    f'Did not restart manager networking service correctly')
+                Console.error('Did not restart manager networking service correctly')
                 sys.exit(1)
             Console.info("Restarted dhcpcd")
             Console.info("Verifying dhcpcd status...")
@@ -302,18 +306,18 @@ class Bridge:
             time.sleep(2)
             if not cls._dhcpcd_active(iface=priv_iface):
                 Console.error(
-                    'Timeout: Could not boot dhcpcd in the allotted amont of time. '
+                    'Timeout: Could not boot dhcpcd in the allotted amohnt of time. '
                     'Use `sudo service dhcpcd status` for more info.')
                 sys.exit(1)
 
-            Console.ok("Verified dhcpcd status successfuly")
+            Console.ok("Verified dhcpcd status successfully")
 
         Console.info("Restarting dnsmasq please wait...")
         status = cls._system('sudo service dnsmasq restart', exitcode=True)
         if status != 0:
-            Console.error(f'Did not restart manager dnsmasq service correctly')
+            Console.error('Did not restart manager dnsmasq service correctly')
             sys.exit(1)
-        Console.ok("Restarted dnsmasq successfuly")
+        Console.ok("Restarted dnsmasq successfully")
 
         Console.ok("Restarted bridge service on manager")
 
@@ -338,7 +342,7 @@ class Bridge:
         try:
             info = readfile('~/.cloudmesh/bridge/info').split('\n')
             info = info[:info.index(cls.lease_bookmark) + 1]
-        except Exception as e:
+        except Exception as e:  # noqa: F841
             Console.error(
                 "Cannot execute info command. Has the bridge been made yet?")
             sys.exit(1)
@@ -356,13 +360,13 @@ class Bridge:
 
             curr_leases = '\n' + '\n'.join(curr_leases)
 
-        except Exception as e:
+        except Exception as e:  # noqa: F841
             Console.warning(
                 "dnsmasq.leases file not found. No devices have been connected yet")
             curr_leases = "\n"
 
         toWrite = '\n'.join(info) + curr_leases
-        sudo_writefile('~/.cloudmesh/bridge/info', toWrite)
+        Sudo.writefile('~/.cloudmesh/bridge/info', toWrite)
 
         banner(toWrite, color='CYAN')
 
@@ -416,7 +420,7 @@ class Bridge:
                     'sudo service dhcpcd status | grep Active')
                 return 'running' in status_line
 
-            # Occassionally dhcpcd fails to start when using WiFi. 
+            # Occasionally dhcpcd fails to start when using WiFi.
             # Unresolved bug as it works after a few restarts
             elif code != 0:
                 if restartCount >= 5:
@@ -464,25 +468,24 @@ class Bridge:
         :return:
         """
         info = textwrap.dedent(f"""
-        IP range: {cls.ip_range[0]} - {cls.ip_range[1]}
-        Manager IP: {cls.masterIP}
+        Manager IP: {cls.managerIP}
 
         {cls.lease_bookmark}
 
         """)
 
         banner(f"""
-        Successfuly configured an internet bridge on this pi. Please reboot 
+        Successfully configured an internet bridge on this pi. Please reboot
         for changes to take effect.
         
         Details:
-          * This bridge will allow devices with ip in the {cls.masterIP}/24 
+          * This bridge will allow devices with ip in the {cls.managerIP}/24
             range to connect to the internet through this pi
-          * Manager Pi has ip {cls.masterIP} on interface {cls.priv_interface}
-        """, color='CYAN')
+          * Manager Pi has ip {cls.managerIP} on interface {cls.priv_interface}
+        """, color='CYAN')  # noqa: W293
 
         cls._system('sudo mkdir -p ~/.cloudmesh/bridge')
-        sudo_writefile('~/.cloudmesh/bridge/info', info)
+        Sudo.writefile('~/.cloudmesh/bridge/info', info)
 
     @classmethod
     def _config_dnsmasq(cls):
@@ -498,7 +501,7 @@ class Bridge:
             Console.info("Configuring dnsmasq...")
             config = textwrap.dedent(f"""
             interface = {cls.priv_interface}
-            listen-address={cls.masterIP}
+            listen-address={cls.managerIP}
 
             dhcp-range={cls.ip_range[0]},{cls.ip_range[1]},{cls.lease}
 
@@ -510,7 +513,7 @@ class Bridge:
             """)
 
             Console.info("Rewriting /etc/dnsmasq.conf")
-            sudo_writefile('/etc/dnsmasq.conf', config)
+            Sudo.writefile('/etc/dnsmasq.conf', config)
 
             # Also add sleep 10 to /etc/init.d/dnsmasq so that it waits for dhcp to start
 
@@ -521,7 +524,7 @@ class Bridge:
                 # The first line in initFile is #!/bin/sh
                 # Move it to index 0 of temp
                 temp[0], temp[1] = temp[1], temp[0]
-                sudo_writefile('/etc/init.d/dnsmasq', '\n'.join(temp) + '\n')
+                Sudo.writefile('/etc/init.d/dnsmasq', '\n'.join(temp) + '\n')
 
     @classmethod
     def _install_dnsmasq(cls):
@@ -533,11 +536,7 @@ class Bridge:
         if cls.dryrun:
             Console.info('Installing dnsmasq...')
         else:
-            banner("""
-
-            Installing dnsmasq. Please wait for installation to complete. 
-
-            """)
+            banner("\n\nInstalling dnsmasq. Please wait for installation to complete.\n\n")
 
             StopWatch.start('install dnsmasq')
             # cls._system(f'sudo apt-get install -y dnsmasq')
@@ -573,7 +572,7 @@ class Bridge:
     @classmethod
     def _dhcpcd_conf(cls):
         """
-        Configures manager with static ip masterIP on interface priv_interface in dhcpcd.conf.
+        Configures manager with static ip managerIP on interface priv_interface in dhcpcd.conf.
         Considered as the IP address of the "default gateway" for the cluster network
         Note: Does not restart dhcpcd.service
 
@@ -581,16 +580,17 @@ class Bridge:
         """
         if cls.dryrun:
             Console.info(
-                f"DRYRUN: Setting ip on {cls.priv_interface} to {cls.masterIP}")
+                f"DRYRUN: Setting ip on {cls.priv_interface} to {cls.managerIP}")
         else:
-            banner(f"""
-            
-            Writing to dhcpcd.conf. Setting static IP of manager to {cls.masterIP} on {cls.priv_interface}
+            banner("\n\nWriting to dhcpcd.conf. Setting static IP "
+                   f"of manager to {cls.managerIP} on {cls.priv_interface}\n\n")
 
-            """)
+            if cls.nameserver:
+                banner(f"\nConfiguring to use nameserver {cls.nameserver}\n")
 
             iface = f'interface {cls.priv_interface}'
-            static_ip = f'static ip_address={cls.masterIP}'
+            static_ip = f'static ip_address={cls.managerIP}/24'
+            static_dns = f'static domain_name_servers={cls.nameserver}'
 
             curr_config = sudo_readfile('/etc/dhcpcd.conf')
             if iface in curr_config:
@@ -602,17 +602,29 @@ class Bridge:
                         Console.warning(
                             "Missing static ip_address assignment. Overwriting line")
                     curr_config[index + 1] = static_ip
-
                 except IndexError:
-                    Console.error('/etc/dhcpcd.conf ends abruptly. Aborting')
-                    sys.exit(1)
-
+                    curr_config.append(static_ip)
+                if cls.nameserver:
+                    try:
+                        if 'static domain_name_servers' not in curr_config[index + 2]:
+                            Console.warning("Missing static domain_name_servers. Overwriting line")
+                        curr_config[index + 2] = static_dns
+                    except IndexError:
+                        curr_config.append(static_dns)
+                else:  # Remove nameserver if it exists
+                    try:
+                        if 'static domain_name_servers' in curr_config[index + 2]:
+                            Console.warning("Found static domain_name_servers, but --dns is not set. Removing line.")
+                        curr_config[index + 2] = ""
+                    except IndexError:
+                        pass
             else:
                 curr_config.append(iface)
                 curr_config.append(static_ip)
-                curr_config.append('nolink\n')
+                if cls.nameserver:
+                    curr_config.append(static_dns)
 
-            sudo_writefile('/etc/dhcpcd.conf', '\n'.join(curr_config))
+            Sudo.writefile('/etc/dhcpcd.conf', '\n'.join(curr_config) + '\n')
             Console.ok('Successfully wrote to /etc/dhcpcd.conf')
 
     @classmethod
@@ -643,11 +655,11 @@ class Bridge:
                         "Could not find iPv4 setting. Perhaps /etc/sysctl.conf "
                         "has been changed from default. Process continues by adding iPv4 setting")
                     old_conf.append('net.ipv4.ip_forward=1')
-                except Exception as e:
+                except Exception as e:  # noqa: F841
                     Console.error(
                         "Could not set iPv4 forwarding. Unknown error occurred")
                 finally:
-                    sudo_writefile('/etc/sysctl.conf', '\n'.join(old_conf))
+                    Sudo.writefile('/etc/sysctl.conf', '\n'.join(old_conf))
             else:
                 Console.info("iPv4 forwarding already set. Skipping iPv4 setup")
 
@@ -660,7 +672,7 @@ class Bridge:
         :return:
         """
         cmd1 = f"sudo iptables -A FORWARD -i {cls.priv_interface} -o {cls.ext_interface} -j ACCEPT"
-        cmd2 = f"sudo iptables -A FORWARD -i {cls.ext_interface} -o {cls.priv_interface}"\
+        cmd2 = f"sudo iptables -A FORWARD -i {cls.ext_interface} -o {cls.priv_interface}" \
                " -m state --state ESTABLISHED,RELATED -j ACCEPT"
         cmd3 = f"sudo iptables -t nat -A POSTROUTING -o {cls.ext_interface} -j MASQUERADE"
 
@@ -685,7 +697,7 @@ class Bridge:
             # Restore rules if reboot
             old_conf = sudo_readfile('/etc/rc.local', trim=True)
 
-            # Exit 0 should be in the last entry of old_conf 
+            # Exit 0 should be in the last entry of old_conf
             # Add ip table restoration lines just above
             restore_command = "iptables-restore < /etc/iptables.ipv4.nat"
 
@@ -700,15 +712,15 @@ class Bridge:
                 old_conf.append(restore_command)
                 old_conf[-1], old_conf[-2] = old_conf[-2], old_conf[
                     -1]  # Places 'exit 0' below our restore_command
-                sudo_writefile('/etc/rc.local', '\n'.join(old_conf) + '\n')
+                Sudo.writefile('/etc/rc.local', '\n'.join(old_conf) + '\n')
 
             else:
-                Console.warning(f"iptables restoration already in rc.local")
+                Console.warning("iptables restoration already in rc.local")
 
     @classmethod
     def _configure_worker_interfaces(cls, worker, user='pi'):
         """
-        Configures the network interface of the worker to use the master as an internet gateway
+        Configures the network interface of the worker to use the manager as an internet gateway
 
         :param worker: A single string hostname for the worker (ie. --hostname option from cm-pi-burn)
         :param user: The user we will use to ssh/scp into the worker
@@ -718,7 +730,7 @@ class Bridge:
         if cls.dryrun:
             Console.info("Configuring worker info.")
             Console.info(
-                f"scp /etc/network/interfaces from {cls.master} to {user}@{worker}")
+                f"scp /etc/network/interfaces from {cls.manager} to {user}@{worker}")
             Console.info(
                 "Configure default gateway and DNS for {cls.priv_interface} on {user}@{worker}")
 
@@ -762,13 +774,13 @@ class Bridge:
                 # Write new interfaces file
                 try:
                     interfaces = readfile(tmp).rstrip().split('\n')
-                except Exception as e:
+                except Exception as e:  # noqa: F841
                     Console.error(f"Could not open {tmp}")
                     sys.exit(1)
 
                 try:
                     ind = interfaces.index(f'auto {cls.priv_interface}')
-                except Exception as e:
+                except Exception as e:  # noqa: F841
                     Console.error(
                         f"Could not find {cls.priv_interface} configuration in interfaces file")
 
@@ -794,6 +806,6 @@ class Bridge:
                     f'ssh {ignore_setting} {user}@{worker} {remote_cmd2}')
 
 # Tests
-# Bridge.create(master='red', workers=['red001'], priv_interface='eth0', ext_interface='wlan0', dryrun=True)
-# Bridge.restart(master='red', workers=['red001'])
+# Bridge.create(manager='red', workers=['red001'], priv_interface='eth0', ext_interface='wlan0', dryrun=True)
+# Bridge.restart(manager='red', workers=['red001'])
 # StopWatch.benchmark(sysinfo=False, csv=False, tag='Testing')
