@@ -5,7 +5,7 @@ class Load(Monitor):
 
     def __init__(self):
         self.title = "Load"
-        self.order = order = [
+        self.order = order = [  # noqa: F841
             'host',
             '1', '5', '10',
             'proc.running', 'proc.total'
@@ -23,7 +23,7 @@ class Load(Monitor):
         entry['5'], \
         entry['10'], \
         procs, \
-        entry['last.pid'] = entry["stdout"].split()
+        entry['last.pid'] = entry["stdout"].split()  # noqa: E122
         entry['proc.running'], entry['proc.total'] = [int(x) for x in
                                                       procs.split("/")]
         for a in '1', '5', '10':
